# Kishor-dl

[![Build Status](https://travis-ci.com/nahid18/kishor-dl.svg?branch=master)](https://travis-ci.com/nahid18/kishor-dl.svg?branch=master)

Kishor-dl is a downloader script for kishorkantha magazine. It uses web scrapping to download more than 150 volumes of magazine.


### Installation

Kishor-dl requires Python3 to run. Install the package by running this on your terminal:
```sh
pip install kishor-dl
```
Then use the below command to import and run the downloader:
```sh
from kishor_dl import kishor
kishor()
```
License
----

MIT